@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: browser.c,v 1.17 1998/11/10 22:14:03 roessler Exp $";
+static const char rcsid[]="$Id: browser.c,v 1.18 1998/12/02 10:04:27 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -443,6 +443,8 @@ static void init_menu (struct browser_state *state, MUTTMENU *menu, char *title,
     menu->current = menu->max - 1;
   if (menu->current < 0)
     menu->current = 0;
+  if (menu->top > menu->current)
+    menu->top = 0;
 
   if (buffy)
     snprintf (title, titlelen, _("Mailboxes [%d]"), mutt_buffy_check (0));
