@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_main.c,v 1.25 1998/11/09 11:15:29 roessler Exp $";
+static const char rcsid[]="$Id: curs_main.c,v 1.26 1998/12/11 08:28:24 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1535,7 +1535,7 @@ int mutt_index_menu (void)
       case OP_MAIL:
 
 	CHECK_ATTACH;
-	ci_send_message (0, NULL, NULL, NULL, NULL);
+	ci_send_message (0, NULL, NULL, Context, NULL);
 	menu->redraw = REDRAW_FULL;
 	break;
 
