@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: getdomain.c,v 1.3 1998/10/15 20:33:27 roessler Exp $";
+static const char rcsid[]="$Id: getdomain.c,v 1.4 1998/11/10 22:14:18 roessler Exp $";
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -29,7 +29,7 @@ int getdnsdomainname (char *s, size_t l)
   {
     p = tmp;
     while (ISSPACE (*p)) p++;
-    if (strncmp ("domain", p, 6) == 0 || strncmp ("search", p, 6) == 0)
+    if (mutt_strncmp ("domain", p, 6) == 0 || mutt_strncmp ("search", p, 6) == 0)
     {
       p += 6;
       while (ISSPACE (*p)) p++;
