@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: history.c,v 1.4 1998/10/15 20:33:34 roessler Exp $";
+static const char rcsid[]="$Id: history.c,v 1.5 1998/11/10 22:14:25 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -75,7 +75,7 @@ void mutt_history_add (history_class_t hclass, const char *s)
   {
     prev = h->last - 1;
     if (prev < 0) prev = HistSize - 1;
-    if (!h->hist[prev] || strcmp (h->hist[prev], s) != 0)
+    if (!h->hist[prev] || mutt_strcmp (h->hist[prev], s) != 0)
     {
       safe_free ((void **) &h->hist[h->last]);
       h->hist[h->last++] = safe_strdup (s);
