@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: parse.c,v 1.17 1998/11/18 22:56:59 roessler Exp $";
+static const char rcsid[]="$Id: parse.c,v 1.18 1998/12/11 07:36:28 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -425,6 +425,8 @@ void mutt_parse_part (FILE *fp, BODY *b)
 	  b->parts = mutt_parse_messageRFC822 (fp, b);
 	else if (mutt_strcasecmp (b->subtype, "external-body") == 0)
 	  b->parts = mutt_read_mime_header (fp, 0);
+	else
+	  return;
       }
       break;
 
@@ -808,6 +810,9 @@ void mutt_parse_mime_message (CONTEXT *ctx, HEADER *cur)
   if (cur->content->type != TYPEMESSAGE && cur->content->type != TYPEMULTIPART)
     return; /* nothing to do */
 
+  if (cur->content->parts)
+    return; /* The message was parsed earlier. */
+
   if ((msg = mx_open_message (ctx, cur->msgno)))
   {
     mutt_parse_part (msg->fp, cur->content);
