@@ -1,4 +1,4 @@
-/* $Id: protos.h,v 1.34 1998/11/18 22:57:02 roessler Exp $ */
+/* $Id: protos.h,v 1.36 1998/11/23 21:10:12 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -237,7 +237,7 @@ int mutt_invoke_sendmail (ADDRESS *, ADDRESS *, ADDRESS *, const char *, int);
 int mutt_is_autoview (char *);
 int mutt_is_mail_list (ADDRESS *);
 int mutt_is_message_type(int, const char *);
-int mutt_is_list_recipient (ADDRESS *a);
+int mutt_is_list_recipient (int, ADDRESS *, ADDRESS *);
 int mutt_is_text_type (int, char *);
 int mutt_is_valid_mailbox (const char *);
 int mutt_multi_choice (char *prompt, char *letters);
@@ -292,7 +292,7 @@ pid_t mutt_create_filter_fd (const char *, FILE **, FILE **, FILE **, int, int,
 
 char *safe_strdup (const char *);
 void *safe_calloc (size_t, size_t);
-void *safe_malloc (unsigned int);
+void *safe_malloc (size_t);
 void safe_realloc (void **, size_t);
 void safe_free (void **);
 
